==> tinybig-0.1.0.post9.tar.gz: tinybig-0.1.0.post9/docs/tutorials/index.md <==
# Tutorials

## Before You Begin

Before reading tutorials in this tab, you may need to first check the [Get Started](../guides/index.md) tab to follow the 
[Installation](../guides/installation.md) guidance to install the latest `tinybig` and its dependency packages. 

Also you are recommended to read the [Quickstart Tutorial](../guides/quick_start.md) to get familiar 
with the basic modules and models provided in the {{toolkit}} toolkit before reading tutorials in this tab.

The tutorials in this tab are primarily prepared based on 
[the RPN paper](https://github.com/jwzhanggy/tinyBIG/blob/main/docs/assets/files/rpn_paper.pdf). 
We recommend reading that paper first for detailed technical information about the {{our}} model and {{toolkit}} toolkit. 


## Tutorial Organization

The tutorials in this tab are organized into two sections.

<div class="grid cards" markdown>

-   :fontawesome-solid-list:{ .middle } __Beginner's Tutorials__

    ---

    The Beginner's Tutorials focus on the fundamental concepts, components, modules, models 
    and tasks about the {{ our }} model, which are organized as follows:
    <ol>
        <li>Tutorials on component functions.</li>
        <li>Tutorials on {{ our }} model building.</li>
        <li>Tutorials on the datasets.</li>
        <li>Tutorials on deep function learning.</li>
    </ol>

    [:octicons-arrow-right-24: Get started](./beginner/index.md)

  -   :fontawesome-solid-table-list:{ .lg .middle } __Advanced Tutorials__

      ---

    The Advanced Tutorials focus on more advanced topics about {{ our }} related to the 
    state-of-the-art deep function learning techniques and tasks.

    The advanced tutorials are still in development, which will be released when they are ready.

    [:octicons-arrow-right-24: More information...](./advanced/index.md)

</div>

==> tinybig-0.1.1.tar.gz: tinybig-0.1.1/docs/tutorials/index.md <==
# Tutorials

## Before You Begin

Before reading tutorials in this tab, you may need to first check the [Get Started](../guides/index.md) tab to follow the 
[Installation](../guides/installation.md) guidance to install the latest `tinybig` and its dependency packages. 

Also you are recommended to read the [Quickstart Tutorial](../guides/quick_start.md) to get familiar 
with the basic modules and models provided in the {{toolkit}} toolkit before reading tutorials in this tab.

The tutorials in this tab are primarily prepared based on 
[the RPN paper](https://github.com/jwzhanggy/tinyBIG/blob/main/docs/assets/files/rpn_paper.pdf). 
We recommend reading that paper first for detailed technical information about the {{our}} model and {{toolkit}} toolkit. 


## Tutorial Organization

The tutorials in this tab are organized into two sections.

<div class="grid cards" markdown>

-   :fontawesome-solid-list:{ .middle } __Beginner's Tutorials__

    ---

    The Beginner's Tutorials focus on the fundamental concepts, components, modules, models 
    and tasks about the {{ our }} model, which are organized as follows:
    <ol>
        <li>Tutorials on component functions.</li>
        <li>Tutorials on {{ our }} model building.</li>
        <li>Tutorials on the datasets.</li>
        <li>Tutorials on function learning tasks.</li>
    </ol>

    [:octicons-arrow-right-24: Get started](./beginner/index.md)

  -   :fontawesome-solid-table-list:{ .lg .middle } __Advanced Tutorials__

      ---

    The Advanced Tutorials focus on more advanced topics about {{ our }} related to the 
    state-of-the-art deep function learning techniques and tasks.

    The advanced tutorials are still in development, which will be released when they are ready.

    [:octicons-arrow-right-24: More information...](./advanced/index.md)

</div>
